@@ -1,7 +1,7 @@
 #ifndef QT_WAYLAND_SERVER_IVI_APPLICATION
 #define QT_WAYLAND_SERVER_IVI_APPLICATION
 
-#include "wayland-server.h"
+#include "wayland-server-core.h"
 #include <QtWaylandCompositor/private/wayland-ivi-application-server-protocol.h>
 #include <QByteArray>
 #include <QMultiMap>
@@ -17,6 +17,7 @@
 QT_BEGIN_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
+QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")
 
 #if !defined(Q_WAYLAND_SERVER_IVI_APPLICATION_EXPORT)
 #  if defined(QT_SHARED)
@@ -44,9 +45,10 @@ namespace QtWaylandServer {
             virtual ~Resource() {}
 
             ivi_surface *ivi_surface_object;
+            ivi_surface *object() { return ivi_surface_object; } 
             struct ::wl_resource *handle;
 
-            struct ::wl_client *client() const { return handle->client; }
+            struct ::wl_client *client() const { return wl_resource_get_client(handle); }
             int version() const { return wl_resource_get_version(handle); }
 
             static Resource *fromResource(struct ::wl_resource *resource);
@@ -126,9 +128,10 @@ namespace QtWaylandServer {
             virtual ~Resource() {}
 
             ivi_application *ivi_application_object;
+            ivi_application *object() { return ivi_application_object; } 
             struct ::wl_resource *handle;
 
-            struct ::wl_client *client() const { return handle->client; }
+            struct ::wl_client *client() const { return wl_resource_get_client(handle); }
             int version() const { return wl_resource_get_version(handle); }
 
             static Resource *fromResource(struct ::wl_resource *resource);
